Skip to contents

Convenience helper returning the posterior median and a credible interval of the correlation between two features across a set of covariate vectors.

Usage

posterior_cor_pair(fit, j, k, xlist, level = 0.95)

Arguments

fit

A fitted "bcaia" object.

j, k

Feature indices.

xlist

A list of covariance-covariate vectors (each length Pcov).

level

Credible level. Default 0.95.

Value

A data frame with columns setting, median, lower, upper.